smartcard.CardConnectionObserver.ConsoleCardConnectionObserver

# ``smartcard`.`CardConnectionObserver`.`ConsoleCardConnectionObserver``

class documentation

`class ConsoleCardConnectionObserver(CardConnectionObserver):`

View In Hierarchy

Undocumented

Method | `update` | Called upon CardConnection event.

def update(self, cardconnection, ccevent):
overrides `smartcard.CardConnectionObserver.CardConnectionObserver.update`

Called upon CardConnection event.

Parameters
cardconnection | the observed card connection object
ccevent | Undocumented
cardconnectionevent | the CardConnectionEvent sent by the connection